package com.shxy.i2.configure;

import lombok.extern.slf4j.Slf4j;
import org.apache.cxf.endpoint.Client;
import org.apache.cxf.jaxws.JaxWsProxyFactoryBean;
import org.apache.cxf.jaxws.endpoint.dynamic.JaxWsDynamicClientFactory;
import org.apache.cxf.transport.http.HTTPConduit;
import org.apache.cxf.transports.http.configuration.HTTPClientPolicy;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

@Configuration
@Slf4j
public class CxfClientConfig {
    @Value("${webservice.address}")
    public String address;
    //
    @Value("${webservice.connecttime}")
    public int connecttime;

    @Value("${webservice.receivetime}")
    public int receivetime;
    /**
     * 采用代理方式
     *
     * @return NBAPlayerSoap
     */
//    @Bean
//    public NBAPlayerSoap createAuthorPortTypeProxy() {
//        JaxWsProxyFactoryBean jaxWsProxyFactoryBean = new JaxWsProxyFactoryBean();
//        jaxWsProxyFactoryBean.setServiceClass(NBAPlayerSoap.class);
//        jaxWsProxyFactoryBean.setAddress(WsConst.SERVICE_ADDRESS);
//        return (NBAPlayerSoap) jaxWsProxyFactoryBean.create();
//    }

    /**
     * 采用动态工厂方式 不需要指定服务接口
     * "http://www.webxml.com.cn/webservices/qqOnlineWebService.asmx?wsdl"
     *
     */
    @Bean
    public Client createDynamicClient() {
        // 动态客户端
        JaxWsDynamicClientFactory clientFactory = JaxWsDynamicClientFactory.newInstance();
        log.info("实时数据 publicsecurity webService url : {}", address);
        //根据WebServices接口地址创建client
        Client client = clientFactory.createClient(address);
        HTTPConduit conduit = (HTTPConduit) client.getConduit();
        HTTPClientPolicy policy = new HTTPClientPolicy();
        policy.setAllowChunking(false);
        // 连接服务器超时时间 60秒
        policy.setConnectionTimeout(connecttime);
        // 等待服务器响应超时时间 60秒
        policy.setReceiveTimeout(receivetime);
        conduit.setClient(policy);
        return client;
    }
}
